@@ -1,3 +1,3 @@
 pub mod collector;
 pub mod retriever;
-pub(crate) const DART: &str = "dart";
+pub const DART: &str = "dart";
